#!/bin/bash

SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
SDK_MANAGER=${SCRIPT_DIR}/sdk/cmdline-tools/bin/sdkmanager
AVD_MANAGER=${SCRIPT_DIR}/sdk/cmdline-tools/bin/avdmanager

if [ ! -e "$SDK_MANAGER" ]; then
  echo  "Setup failed: Unable to find $SDK_MANAGER"
  exit 1
fi

echo "Setting environment variable ANDROID_SDK_ROOT..."
ANDROID_HOME=${SCRIPT_DIR}/sdk
ANDROID_SDK_ROOT=${SCRIPT_DIR}/sdk
export ANDROID_SDK_ROOT="${ANDROID_SDK_ROOT}"
export ANDROID_HOME="${ANDROID_HOME}"

pushd "${SCRIPT_DIR}"

if [ ! -d /var/root/.android ]; then
  echo "Creating Android settings directory..."
  mkdir /var/root/.android
fi

if [ ! -e /var/root/.android/repositories.cfg ]; then
  echo "Creating placeholder repository file..."
  touch /var/root/.android/repositories.cfg
  EMPTY_REPO_CFG=1
fi

echo "Installing Android Platform Tools..."
"${SDK_MANAGER}" --sdk_root=${ANDROID_HOME} "platform-tools"
echo "Installing Android Emulator..."
"${SDK_MANAGER}" --sdk_root=${ANDROID_HOME} "emulator"
echo "Installing Google Play Services..."
"${SDK_MANAGER}" --sdk_root=${ANDROID_HOME} "extras;google;google_play_services"
echo "Installing Android Support Repository..."
"${SDK_MANAGER}" --sdk_root=${ANDROID_HOME} "extras;android;m2repository"
echo "Installing Google Repository..."
"${SDK_MANAGER}" --sdk_root=${ANDROID_HOME} "extras;google;m2repository"

for v in "29.0.3" "30.0.3" "31.0.0";  do
  echo "Installing Android Build Tools ${v}..."
  "${SDK_MANAGER}" --sdk_root=${ANDROID_HOME} "build-tools;${v}"
done

for v in "26" "28" "29" "30"; do
  echo "Installing Android SDK Platform ${v}..."
  "${SDK_MANAGER}" --sdk_root=${ANDROID_HOME} "platforms;android-${v}"
  echo "Installing Android SDK Platform ${v} sources..."
  "${SDK_MANAGER}" --sdk_root=${ANDROID_HOME} "sources;android-${v}"
done

for v in {28..30}; do
  echo "Google Play Intel x86 Atom System Image ${v}..."
  "${SDK_MANAGER}" --sdk_root=${ANDROID_HOME} "system-images;android-${v};google_apis_playstore;x86_64"
done

echo Updating Android SDK Tools...
"${SDK_MANAGER}" --sdk_root=${ANDROID_HOME} --update

echo "Cleaning temporary files..."
[[ "$EMPTY_REPO_CFG" = "1" ]] && rm -f ~/.android/repositories.cfg

echo "Setting permissions..."
[ $SUDO_USER ] && user=$SUDO_USER || user=`whoami`
chown -R "${user}" .

echo "Storing system environment variable ANDROID_HOME and ANDROID_SDK_ROOT..."
echo export "ANDROID_SDK_ROOT=${ANDROID_SDK_ROOT}" >> ~/.bash_profile
echo export "ANDROID_HOME=${ANDROID_HOME}" >> ~/.bash_profile

echo "Setup complete."

popd
