@echo off

SET SDK_MANAGER=%~dp0sdk\cmdline-tools\bin\sdkmanager.bat
SET AVD_MANAGER=%~dp0sdk\cmdline-tools\bin\avdmanager.bat

SET API_LIST=26 28 29 30
SET START_IMAGE=28
SET END_IMAGE=30
SET BUILD_TOOLS_LIST=29.0.3 30.0.3 31.0.0

if not exist %SDK_MANAGER% (
  echo  Setup failed: Unable to find %SDK_MANAGER%
  exit /B 1
)

echo Setting environment variables ANDROID_HOME and ANDROID_SDK_ROOT...
set ANDROID_SDK_ROOT=%~dp0sdk
set ANDROID_HOME=%~dp0sdk

pushd "%~dp0"

if not exist "%USERPROFILE%\.android" (
  echo Creating Android settings directory...
  mkdir "%USERPROFILE%\.android"
)

if not exist "%USERPROFILE%\.android\repositories.cfg" (
  echo Creating placeholder repository file...
  copy NUL "%USERPROFILE%\.android\repositories.cfg"
  set __EMPTY_REPO_CFG__=1
)

echo Installing Android Platform Tools...
call "%SDK_MANAGER%" --sdk_root=%ANDROID_HOME% platform-tools
echo Installing Android Emulator...
call "%SDK_MANAGER%" --sdk_root=%ANDROID_HOME% emulator
echo Installing Google USB Driver...
call "%SDK_MANAGER%" --sdk_root=%ANDROID_HOME% extras;google;usb_driver
echo Installing Google Play Services...
call "%SDK_MANAGER%" --sdk_root=%ANDROID_HOME% extras;google;google_play_services
echo Installing Android Support Repository...
call "%SDK_MANAGER%" --sdk_root=%ANDROID_HOME% extras;android;m2repository
echo Installing Google Repository...
call "%SDK_MANAGER%" --sdk_root=%ANDROID_HOME% extras;google;m2repository

for %%v in (%BUILD_TOOLS_LIST%) do (
  echo Installing Android Build Tools %%v...
  call "%SDK_MANAGER%" --sdk_root=%ANDROID_HOME% build-tools;%%v
)

for %%v in (%API_LIST%) do (
  echo Installing Android SDK Platform %%v...
  call "%SDK_MANAGER%" --sdk_root=%ANDROID_HOME% platforms;android-%%v
  echo Installing Android SDK Platform %%v sources...
  call "%SDK_MANAGER%" --sdk_root=%ANDROID_HOME% sources;android-%%v
)

for /L %%v in (%START_IMAGE%,1,%END_IMAGE%) do (
  echo Google Play Intel x86 Atom System Image %%v...
  call "%SDK_MANAGER%" --sdk_root=%ANDROID_HOME% system-images;android-%%v;google_apis_playstore;x86_64
)

echo Updating Android SDK Tools...
call "%SDK_MANAGER%" --sdk_root=%ANDROID_HOME% --update

echo Cleaning temporary files...
if [%__EMPTY_REPO_CFG__%] == [1] (
    del "%USERPROFILE%\.android\repositories.cfg"
)

echo Storing system environment variable ANDROID_SDK_ROOT and ANDROID_HOME...
setx ANDROID_SDK_ROOT "%ANDROID_SDK_ROOT%" /M
setx ANDROID_HOME %%ANDROID_SDK_ROOT%% /M

echo Setup complete.

popd
